@@ -15,7 +15,7 @@ use Scope::Guard;
 
 use Exporter qw(import);
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 our @EXPORT_OK = qw(start_server restart_server server_ports);
 
 my @signals_received;
@@ -285,7 +285,7 @@ sub _start_worker {
         if ($pid == 0) {
             my @args = @{$opts->{exec}};
             # child process
-            if ( exists $opts->{dir} ) {
+            if (defined $opts->{dir}) {
                 chdir $opts->{dir} or die "failed to chdir:$!";
             }
             { exec { $args[0] } @args };
